@@ -16,11 +16,11 @@ FIRST_DAY_OF_WEEK = 1  # Monday
 
 # The *_INPUT_FORMATS strings use the Python strftime format syntax,
 # see http://docs.python.org/library/datetime.html#strftime-strptime-behavior
-DATE_INPUT_FORMATS = (
+DATE_INPUT_FORMATS = [
     '%d.%m.%Y',  # '20.3.2014'
     '%d.%m.%y',  # '20.3.14'
-)
-DATETIME_INPUT_FORMATS = (
+]
+DATETIME_INPUT_FORMATS = [
     '%d.%m.%Y %H.%M.%S',     # '20.3.2014 14.30.59'
     '%d.%m.%Y %H.%M.%S.%f',  # '20.3.2014 14.30.59.000200'
     '%d.%m.%Y %H.%M',        # '20.3.2014 14.30'
@@ -30,12 +30,12 @@ DATETIME_INPUT_FORMATS = (
     '%d.%m.%y %H.%M.%S.%f',  # '20.3.14 14.30.59.000200'
     '%d.%m.%y %H.%M',        # '20.3.14 14.30'
     '%d.%m.%y',              # '20.3.14'
-)
-TIME_INPUT_FORMATS = (
+]
+TIME_INPUT_FORMATS = [
     '%H.%M.%S',     # '14.30.59'
     '%H.%M.%S.%f',  # '14.30.59.000200'
     '%H.%M',        # '14.30'
-)
+]
 
 DECIMAL_SEPARATOR = ','
 THOUSAND_SEPARATOR = '\xa0'  # Non-breaking space
